alloc_f64_array

Function alloc_f64_array 

pub fn alloc_f64_array(len: usize) -> usize
Allocate len f64 values in WASM linear memory.

Returns a pointer (as usize) to the start of the allocated buffer. The caller is responsible for eventually freeing the buffer by passing the same pointer and length to free_f64_array.

Returns 0 when len is zero; panics on allocation failure.