pub struct WasmArray { /* private fields */ }Expand description
A wrapper around ndarray for JavaScript interop
Implementations
Sourceimpl WasmArray
impl WasmArray
Sourcepub fn new(data: &JsValue) -> Result<WasmArray, JsValue>
pub fn new(data: &JsValue) -> Result<WasmArray, JsValue>
Create a 1D array from a JavaScript array or typed array
Sourcepub fn from_shape(shape: &JsValue, data: &JsValue) -> Result<WasmArray, JsValue>
pub fn from_shape(shape: &JsValue, data: &JsValue) -> Result<WasmArray, JsValue>
Create an array with a specific shape from flat data
Sourcepub fn zeros(shape: &JsValue) -> Result<WasmArray, JsValue>
pub fn zeros(shape: &JsValue) -> Result<WasmArray, JsValue>
Create an array of zeros with the given shape
Sourcepub fn ones(shape: &JsValue) -> Result<WasmArray, JsValue>
pub fn ones(shape: &JsValue) -> Result<WasmArray, JsValue>
Create an array of ones with the given shape
Sourcepub fn full(shape: &JsValue, value: f64) -> Result<WasmArray, JsValue>
pub fn full(shape: &JsValue, value: f64) -> Result<WasmArray, JsValue>
Create an array filled with a constant value
Sourcepub fn linspace(start: f64, end: f64, num: usize) -> Result<WasmArray, JsValue>
pub fn linspace(start: f64, end: f64, num: usize) -> Result<WasmArray, JsValue>
Create an evenly spaced array (like numpy.linspace)
Sourcepub fn arange(start: f64, end: f64, step: f64) -> Result<WasmArray, JsValue>
pub fn arange(start: f64, end: f64, step: f64) -> Result<WasmArray, JsValue>
Create an array with evenly spaced values (like numpy.arange)
Sourcepub fn to_array(&self) -> Float64Array
pub fn to_array(&self) -> Float64Array
Convert to a flat JavaScript Float64Array
Sourcepub fn to_nested_array(&self) -> JsValue
pub fn to_nested_array(&self) -> JsValue
Convert to a JavaScript array (nested for multi-dimensional arrays)
Sourcepub fn get(&self, index: usize) -> Result<f64, JsValue>
pub fn get(&self, index: usize) -> Result<f64, JsValue>
Get a value at the specified index (flat indexing)